@@ -49,6 +49,14 @@ class Charsets
     );
 
     private static $_charsets = array();
+
+    /**
+     * The charset for the server
+     *
+     * @var string
+     */
+    private static $_charset_server;
+
     private static $_charsets_descriptions = array();
     private static $_collations = array();
     private static $_default_collations = array();
@@ -127,6 +135,23 @@ class Charsets
         }
     }
 
+     /**
+     * Get current MySQL server charset.
+     *
+     * @param DatabaseInterface $dbi DatabaseInterface instance
+     *
+     * @return string
+     */
+    public static function getServerCharset(DatabaseInterface $dbi)
+    {
+        if (self::$_charset_server) {
+            return self::$_charset_server;
+        } else {
+            self::$_charset_server = $dbi->getVariable('character_set_server');
+            return self::$_charset_server;
+        }
+    }
+
     /**
      * Get MySQL charsets
      *
