@@ -6,9 +6,15 @@
  *
  * @package PhpMyAdmin
  */
-use PMA\libraries\Response;
-use PMA\libraries\Table;
-use PMA\Util;
+
+use PhpMyAdmin\Di\Container;
+use PhpMyAdmin\Partition;
+use PhpMyAdmin\Relation;
+use PhpMyAdmin\Response;
+use PhpMyAdmin\Table;
+use PhpMyAdmin\Template;
+use PhpMyAdmin\Transformations;
+use PhpMyAdmin\Util;
 
 if (!defined('PHPMYADMIN')) {
     exit;
@@ -17,14 +23,14 @@ if (!defined('PHPMYADMIN')) {
 /**
  * Check parameters
  */
-require_once 'libraries/util.lib.php';
-
-PMA\libraries\Util::checkParameters(
+Util::checkParameters(
     array('server', 'db', 'table', 'action', 'num_fields')
 );
 
 global $db, $table;
 
+$relation = new Relation();
+
 /**
  * Initialize to avoid code execution path warnings
  */
@@ -54,10 +60,10 @@ if ($action == 'tbl_create.php') {
     if ($action == 'tbl_addfield.php') {
         $form_params = array_merge(
             $form_params, array(
-            'field_where' => Util\get($_REQUEST, 'field_where'))
+            'field_where' => Util::getValueByKey($_POST, 'field_where'))
         );
-        if (isset($_REQUEST['field_where'])) {
-            $form_params['after_field'] = $_REQUEST['after_field'];
+        if (isset($_POST['field_where'])) {
+            $form_params['after_field'] = $_POST['after_field'];
         }
     }
     $form_params['table'] = $table;
@@ -70,8 +76,8 @@ if (isset($num_fields)) {
 $form_params = array_merge(
     $form_params,
     array(
-        'orig_field_where' => Util\get($_REQUEST, 'field_where'),
-        'orig_after_field' => Util\get($_REQUEST, 'after_field'),
+        'orig_field_where' => Util::getValueByKey($_POST, 'field_where'),
+        'orig_after_field' => Util::getValueByKey($_POST, 'after_field'),
     )
 );
 
@@ -83,22 +89,21 @@ if (isset($selected) && is_array($selected)) {
 
 $is_backup = ($action != 'tbl_create.php' && $action != 'tbl_addfield.php');
 
-require_once './libraries/transformations.lib.php';
-$cfgRelation = PMA_getRelationsParam();
+$cfgRelation = $relation->getRelationsParam();
 
-$comments_map = PMA_getComments($db, $table);
+$comments_map = $relation->getComments($db, $table);
 
 $move_columns = array();
 if (isset($fields_meta)) {
-    /** @var PMA\libraries\DatabaseInterface $dbi */
-    $dbi = \PMA\libraries\di\Container::getDefaultContainer()->get('dbi');
+    /** @var PhpMyAdmin\DatabaseInterface $dbi */
+    $dbi = Container::getDefaultContainer()->get('dbi');
     $move_columns = $dbi->getTable($db, $table)->getColumnsMeta();
 }
 
 $available_mime = array();
 if ($cfgRelation['mimework'] && $GLOBALS['cfg']['BrowseMIME']) {
-    $mime_map = PMA_getMIME($db, $table);
-    $available_mime = PMA_getAvailableMIMEtypes();
+    $mime_map = Transformations::getMIME($db, $table);
+    $available_mime = Transformations::getAvailableMIMEtypes();
 }
 
 //  workaround for field_fulltext, because its submitted indices contain
@@ -109,19 +114,19 @@ if (isset($field_fulltext) && is_array($field_fulltext)) {
         $submit_fulltext[$fulltext_indexkey] = $fulltext_indexkey;
     }
 }
-if (isset($_REQUEST['submit_num_fields'])
-    || isset($_REQUEST['submit_partition_change'])
+if (isset($_POST['submit_num_fields'])
+    || isset($_POST['submit_partition_change'])
 ) {
     //if adding new fields, set regenerate to keep the original values
     $regenerate = 1;
 }
 
-$foreigners = PMA_getForeigners($db, $table, '', 'foreign');
+$foreigners = $relation->getForeigners($db, $table, '', 'foreign');
 $child_references = null;
 // From MySQL 5.6.6 onwards columns with foreign keys can be renamed.
 // Hence, no need to get child references
-if (PMA_MYSQL_INT_VERSION < 50606) {
-    $child_references = PMA_getChildReferences($db, $table);
+if ($GLOBALS['dbi']->getVersion() < 50606) {
+    $child_references = $relation->getChildReferences($db, $table);
 }
 
 for ($columnNumber = 0; $columnNumber < $num_fields; $columnNumber++) {
@@ -137,42 +142,42 @@ for ($columnNumber = 0; $columnNumber < $num_fields; $columnNumber++) {
         $columnMeta = array_merge(
             $columnMeta,
             array(
-                'Field'        => Util\get(
-                    $_REQUEST, "field_name.${columnNumber}", false
+                'Field'        => Util::getValueByKey(
+                    $_POST, "field_name.${columnNumber}", false
                 ),
-                'Type'         => Util\get(
-                    $_REQUEST, "field_type.${columnNumber}", false
+                'Type'         => Util::getValueByKey(
+                    $_POST, "field_type.${columnNumber}", false
                 ),
-                'Collation'    => Util\get(
-                    $_REQUEST, "field_collation.${columnNumber}", ''
+                'Collation'    => Util::getValueByKey(
+                    $_POST, "field_collation.${columnNumber}", ''
                 ),
-                'Null'         => Util\get(
-                    $_REQUEST, "field_null.${columnNumber}", ''
+                'Null'         => Util::getValueByKey(
+                    $_POST, "field_null.${columnNumber}", ''
                 ),
-                'DefaultType'  => Util\get(
-                    $_REQUEST, "field_default_type.${columnNumber}", 'NONE'
+                'DefaultType'  => Util::getValueByKey(
+                    $_POST, "field_default_type.${columnNumber}", 'NONE'
                 ),
-                'DefaultValue' => Util\get(
-                    $_REQUEST, "field_default_value.${columnNumber}", ''
+                'DefaultValue' => Util::getValueByKey(
+                    $_POST, "field_default_value.${columnNumber}", ''
                 ),
-                'Extra'        => Util\get(
-                    $_REQUEST, "field_extra.${columnNumber}", false
+                'Extra'        => Util::getValueByKey(
+                    $_POST, "field_extra.${columnNumber}", false
                 ),
-                'Virtuality'   => Util\get(
-                    $_REQUEST, "field_virtuality.${columnNumber}", ''
+                'Virtuality'   => Util::getValueByKey(
+                    $_POST, "field_virtuality.${columnNumber}", ''
                 ),
-                'Expression'   => Util\get(
-                    $_REQUEST, "field_expression.${columnNumber}", ''
+                'Expression'   => Util::getValueByKey(
+                    $_POST, "field_expression.${columnNumber}", ''
                 ),
             )
         );
 
         $columnMeta['Key'] = '';
         $parts = explode(
-            '_', Util\get($_REQUEST, "field_key.${columnNumber}", ''), 2
+            '_', Util::getValueByKey($_POST, "field_key.${columnNumber}", ''), 2
         );
         if (count($parts) == 2 && $parts[1] == $columnNumber) {
-            $columnMeta['Key'] = Util\get(
+            $columnMeta['Key'] = Util::getValueByKey(
                 array(
                     'primary' => 'PRI',
                     'index' => 'MUL',
@@ -198,27 +203,28 @@ for ($columnNumber = 0; $columnNumber < $num_fields; $columnNumber++) {
             break;
         case 'NULL':
         case 'CURRENT_TIMESTAMP':
+        case 'current_timestamp()':
             $columnMeta['Default'] = $columnMeta['DefaultType'];
             break;
         }
 
-        $length = Util\get($_REQUEST, "field_length.${columnNumber}", $length);
-        $submit_attribute = Util\get(
-            $_REQUEST, "field_attribute.${columnNumber}", false
+        $length = Util::getValueByKey($_POST, "field_length.${columnNumber}", $length);
+        $submit_attribute = Util::getValueByKey(
+            $_POST, "field_attribute.${columnNumber}", false
         );
-        $comments_map[$columnMeta['Field']] = Util\get(
-            $_REQUEST, "field_comments.${columnNumber}"
+        $comments_map[$columnMeta['Field']] = Util::getValueByKey(
+            $_POST, "field_comments.${columnNumber}"
         );
 
         $mime_map[$columnMeta['Field']] = array_merge(
             $mime_map[$columnMeta['Field']],
             array(
-                'mimetype' => Util\get($_REQUEST, "field_mimetype.${$columnNumber}"),
-                'transformation' => Util\get(
-                    $_REQUEST, "field_transformation.${$columnNumber}"
+                'mimetype' => Util::getValueByKey($_POST, "field_mimetype.${$columnNumber}"),
+                'transformation' => Util::getValueByKey(
+                    $_POST, "field_transformation.${$columnNumber}"
                 ),
-                'transformation_options' => Util\get(
-                    $_REQUEST, "field_transformation_options.${$columnNumber}"
+                'transformation_options' => Util::getValueByKey(
+                    $_POST, "field_transformation_options.${$columnNumber}"
                 ),
             )
         );
@@ -251,6 +257,7 @@ for ($columnNumber = 0; $columnNumber < $num_fields; $columnNumber++) {
             }
             break;
         case 'CURRENT_TIMESTAMP':
+        case 'current_timestamp()':
             $columnMeta['DefaultType'] = 'CURRENT_TIMESTAMP';
             $columnMeta['DefaultValue'] = '';
             break;
@@ -262,12 +269,12 @@ for ($columnNumber = 0; $columnNumber < $num_fields; $columnNumber++) {
     }
 
     if (isset($columnMeta['Type'])) {
-        $extracted_columnspec = PMA\libraries\Util::extractColumnSpec(
+        $extracted_columnspec = Util::extractColumnSpec(
             $columnMeta['Type']
         );
         if ($extracted_columnspec['type'] == 'bit') {
             $columnMeta['Default']
-                = PMA\libraries\Util::convertBitDefaultValue($columnMeta['Default']);
+                = Util::convertBitDefaultValue($columnMeta['Default']);
         }
         $type = $extracted_columnspec['type'];
         if ($length == '') {
@@ -282,9 +289,9 @@ for ($columnNumber = 0; $columnNumber < $num_fields; $columnNumber++) {
     // MySQL version from 5.6.6 allow renaming columns with foreign keys
     if (isset($columnMeta['Field'])
         && isset($form_params['table'])
-        && PMA_MYSQL_INT_VERSION < 50606
+        && $GLOBALS['dbi']->getVersion() < 50606
     ) {
-        $columnMeta['column_status'] = PMA_checkChildForeignReferences(
+        $columnMeta['column_status'] = $relation->checkChildForeignReferences(
             $form_params['db'],
             $form_params['table'],
             $columnMeta['Field'],
@@ -340,31 +347,31 @@ for ($columnNumber = 0; $columnNumber < $num_fields; $columnNumber++) {
         $form_params = array_merge(
             $form_params,
             array(
-                "field_default_value_orig[${columnNumber}]" => Util\get(
+                "field_default_value_orig[${columnNumber}]" => Util::getValueByKey(
                     $columnMeta, 'Default', ''
                 ),
-                "field_default_type_orig[${columnNumber}]"  => Util\get(
+                "field_default_type_orig[${columnNumber}]"  => Util::getValueByKey(
                     $columnMeta, 'DefaultType', ''
                 ),
-                "field_collation_orig[${columnNumber}]"     => Util\get(
+                "field_collation_orig[${columnNumber}]"     => Util::getValueByKey(
                     $columnMeta, 'Collation', ''
                 ),
                 "field_attribute_orig[${columnNumber}]"     => trim(
-                    Util\get($extracted_columnspec, 'attribute', '')
+                    Util::getValueByKey($extracted_columnspec, 'attribute', '')
                 ),
-                "field_null_orig[${columnNumber}]"          => Util\get(
+                "field_null_orig[${columnNumber}]"          => Util::getValueByKey(
                     $columnMeta, 'Null', ''
                 ),
-                "field_extra_orig[${columnNumber}]"         => Util\get(
+                "field_extra_orig[${columnNumber}]"         => Util::getValueByKey(
                     $columnMeta, 'Extra', ''
                 ),
-                "field_comments_orig[${columnNumber}]"      => Util\get(
+                "field_comments_orig[${columnNumber}]"      => Util::getValueByKey(
                     $columnMeta, 'Comment', ''
                 ),
-                "field_virtuality_orig[${columnNumber}]"    => Util\get(
+                "field_virtuality_orig[${columnNumber}]"    => Util::getValueByKey(
                     $columnMeta, 'Virtuality', ''
                 ),
-                "field_expression_orig[${columnNumber}]"    => Util\get(
+                "field_expression_orig[${columnNumber}]"    => Util::getValueByKey(
                     $columnMeta, 'Expression', ''
                 ),
             )
@@ -372,8 +379,8 @@ for ($columnNumber = 0; $columnNumber < $num_fields; $columnNumber++) {
     }
 
     $content_cells[$columnNumber] = array(
-        'columnNumber' => $columnNumber,
-        'columnMeta' => $columnMeta,
+        'column_number' => $columnNumber,
+        'column_meta' => $columnMeta,
         'type_upper' => mb_strtoupper($type),
         'length_values_input_size' => $length_values_input_size,
         'length' => $length,
@@ -383,30 +390,53 @@ for ($columnNumber = 0; $columnNumber < $num_fields; $columnNumber++) {
         'fields_meta' => isset($fields_meta) ? $fields_meta : null,
         'is_backup' => $is_backup,
         'move_columns' => $move_columns,
-        'cfgRelation' => $cfgRelation,
+        'cfg_relation' => $cfgRelation,
         'available_mime' => $available_mime,
         'mime_map' => isset($mime_map) ? $mime_map : array()
     );
 } // end for
 
-$html = PMA\libraries\Template::get('columns_definitions/column_definitions_form')
-    ->render(
-        array(
-            'is_backup'     => $is_backup,
-            'fields_meta'   => isset($fields_meta) ? $fields_meta : null,
-            'mimework'      => $cfgRelation['mimework'],
-            'action'        => $action,
-            'form_params'   => $form_params,
-            'content_cells' => $content_cells,
-        )
-    );
+include 'libraries/tbl_partition_definition.inc.php';
+$html = Template::get('columns_definitions/column_definitions_form')->render([
+    'is_backup' => $is_backup,
+    'fields_meta' => isset($fields_meta) ? $fields_meta : null,
+    'mimework' => $cfgRelation['mimework'],
+    'action' => $action,
+    'form_params' => $form_params,
+    'content_cells' => $content_cells,
+    'partition_details' => $partitionDetails,
+    'primary_indexes' => isset($_POST['primary_indexes']) ? $_POST['primary_indexes'] : null,
+    'unique_indexes' => isset($_POST['unique_indexes']) ? $_POST['unique_indexes'] : null,
+    'indexes' => isset($_POST['indexes']) ? $_POST['indexes'] : null,
+    'fulltext_indexes' => isset($_POST['fulltext_indexes']) ? $_POST['fulltext_indexes'] : null,
+    'spatial_indexes' => isset($_POST['spatial_indexes']) ? $_POST['spatial_indexes'] : null,
+    'table' => isset($_POST['table']) ? $_POST['table'] : null,
+    'comment' => isset($_POST['comment']) ? $_POST['comment'] : null,
+    'tbl_collation' => isset($_POST['tbl_collation']) ? $_POST['tbl_collation'] : null,
+    'tbl_storage_engine' => isset($_POST['tbl_storage_engine']) ? $_POST['tbl_storage_engine'] : null,
+    'connection' => isset($_POST['connection']) ? $_POST['connection'] : null,
+    'change_column' => isset($_POST['change_column']) ? $_POST['change_column'] : null,
+    'is_virtual_columns_supported' => Util::isVirtualColumnsSupported(),
+    'browse_mime' => isset($GLOBALS['cfg']['BrowseMIME']) ? $GLOBALS['cfg']['BrowseMIME'] : null,
+    'server_type' => Util::getServerType(),
+    'max_rows' => intval($GLOBALS['cfg']['MaxRows']),
+    'char_editing' => isset($GLOBALS['cfg']['CharEditing']) ? $GLOBALS['cfg']['CharEditing'] : null,
+    'attribute_types' => $GLOBALS['dbi']->types->getAttributes(),
+    'privs_available' => (isset($GLOBALS['col_priv']) ? $GLOBALS['col_priv'] : false
+        && isset($GLOBALS['is_reload_priv']) ? $GLOBALS['is_reload_priv'] : false
+    ),
+    'max_length' => $GLOBALS['dbi']->getVersion() >= 50503 ? 1024 : 255,
+    'have_partitioning' => Partition::havePartitioning(),
+    'dbi' => $GLOBALS['dbi'],
+    'disable_is' => $GLOBALS['cfg']['Server']['DisableIS'],
+]);
 
 unset($form_params);
 
 $response = Response::getInstance();
 $response->getHeader()->getScripts()->addFiles(
     array(
-        'jquery/jquery.uitablefilter.js',
+        'vendor/jquery/jquery.uitablefilter.js',
         'indexes.js'
     )
 );
